summaryrefslogtreecommitdiffstats
path: root/kdesktop/kcustommenu.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kdesktop/kcustommenu.cc
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdesktop/kcustommenu.cc')
-rw-r--r--kdesktop/kcustommenu.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdesktop/kcustommenu.cc b/kdesktop/kcustommenu.cc
index 2a6b64ec6..1d39a093d 100644
--- a/kdesktop/kcustommenu.cc
+++ b/kdesktop/kcustommenu.cc
@@ -81,8 +81,8 @@ KCustomMenu::insertMenuItem(KService::Ptr & s, int nId, int nIndex/*= -1*/)
TQString serviceName = s->name();
// item names may contain ampersands. To avoid them being converted
- // to accelators, tqreplace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ // to accelators, replace them with two ampersands.
+ serviceName.replace("&", "&&");
TQPixmap normal = KGlobal::instance()->iconLoader()->loadIcon(s->icon(), KIcon::Small,
0, KIcon::DefaultState, 0L, true);